@@ -40,7 +40,7 @@ namespace code {
 	BITMASK_OPERATORS(FreeOpt);
 
 	wostream &operator <<(wostream &to, FreeOpt o);
-	StrBuf &operator <<(StrBuf &to, FreeOpt o);
+	StrBuf &STORM_FN operator <<(StrBuf &to, FreeOpt o);
 
 
 	/**
@@ -105,6 +105,9 @@ namespace code {
 
 			// Add a label here.
 			void add(Engine &e, Label label);
+
+			// Output.
+			void STORM_FN toS(StrBuf *to) const;
 		};
 
 		// Add instructions and labels.
@@ -431,8 +434,6 @@ namespace code {
 		void putVar(StrBuf &to, Nat var) const;
 	};
 
-	StrBuf &STORM_FN operator <<(StrBuf &to, Listing::Entry e);
-
 	// Insert a nop instruction if the last instruction was a call instruction.
 	// This is needed on some backends because the function return addresses are
 	// otherwise treated as if the next instruction faulted and is to be re-tried.
