@@ -373,7 +373,26 @@ namespace storm {
 		return s;
 	}
 
-	void Type::setThread(NamedThread *thread) {
+	Bool Type::setThread(NamedThread *thread) {
+		// Can't set threads for value types.
+		if (value())
+			return false;
+
+		if (Type *currentSuper = super()) {
+			// If the current super-type is something other than the base-class Object, or the base
+			// class has a 'useThread' configured, disallow setting the thread here:
+			Type *objType = Object::stormType(engine);
+			if (isA(objType) && currentSuper != objType) {
+				// We inherit indirectly from a class-type. Don't allow introducing TObject.
+				return false;
+			} else if (isA(TObject::stormType(engine))) {
+				// Disallow if the super type has its 'useThread' set:
+				if (currentSuper->useThread != null) {
+					return false;
+				}
+			}
+		}
+
 		useThread = thread;
 
 		Type *def = defaultSuper();
@@ -383,6 +402,8 @@ namespace storm {
 
 		// Propagate the current thread to any child types.
 		notifyThread(thread);
+
+		return true;
 	}
 
 	RunOn Type::runOn() {
@@ -459,7 +480,7 @@ namespace storm {
 			// Tell the layout we found a new variable!
 			if (!layout)
 				layout = new (engine) Layout();
-			layout->add(item);
+			layout->add(item, this);
 		}
 	}
 
@@ -477,12 +498,6 @@ namespace storm {
 			return null;
 	}
 
-	void Type::notifyAdded(NameSet *, Named *what) {
-		if (Function *f = as<Function>(what)) {
-			updateHandleToS(false, f);
-		}
-	}
-
 	void Type::notifyThread(NamedThread *thread) {
 		useThread = thread;
 
@@ -656,6 +671,12 @@ namespace storm {
 
 		// We might as well compute our size while we're at it!
 		mySize = layout->doLayout(superSize());
+
+		// Since we have computed our size, it means that we can be instantiated. Because of that,
+		// make sure that the destructor is compiled now. Otherwise, it might be compiled during
+		// shutdown, which is likely to fail:
+		if (Function *dtor = destructor())
+			dtor->compile();
 	}
 
 	Array<MemberVar *> *Type::variables() const {
@@ -705,6 +726,13 @@ namespace storm {
 			// If we do not have a layout, we do not have any variables.
 			mySize = layout->doLayout(mySize);
 		}
+
+		// Since we have computed our size, it means that we can be instantiated. Because of that,
+		// make sure that the destructor is compiled now. Otherwise, it might be compiled during
+		// shutdown, which is likely to fail:
+		if (Function *dtor = destructor())
+			dtor->compile();
+
 		return mySize;
 	}
 
@@ -739,13 +767,12 @@ namespace storm {
 	}
 
 	static void defToS(const void *obj, StrBuf *to) {
-		*to << S("<operator << not found>");
+		*to << S("<no member toS(StrBuf) or toS()>");
 	}
 
 	const Handle &Type::handle() {
 		// If we're completely done with the handle, return it immediatly.
-		// If it is 'toSMissing', there is nothing we can do but wait until we get notified by the parent.
-		if (tHandle && (handleToS == toSFound || handleToS == toSMissing))
+		if (tHandle)
 			return *tHandle;
 
 		// We need to create the handle. Switch threads.
@@ -761,9 +788,6 @@ namespace storm {
 
 		if (!tHandle)
 			buildHandle();
-		if (handleToS != toSFound)
-			// NOTE: This does not really help when 'handleToS == toSMissing'...
-			updateHandleToS(false, null);
 		return *tHandle;
 	}
 
@@ -1059,6 +1083,7 @@ namespace storm {
 			h->copyFn = null; // Memcpy is OK.
 			h->deepCopyFn = &objDeepCopy;
 			h->toSFn = &objToS;
+			handleToS = toSWithParam;
 		}
 
 		// Populate the handle for some types manually. Otherwise, we will not be able to boot
@@ -1086,7 +1111,18 @@ namespace storm {
 			if (Function *f = deepCopyFn())
 				updateHandle(f);
 
-			updateHandleToS(true, null);
+			// Find toS.
+			Array<Value> *rb = new (engine) Array<Value>(2, thisPtr(this));
+			rb->at(1) = Value(StormInfo<StrBuf>::type(engine));
+
+			if (Function *f = as<Function>(find(S("toS"), rb, scope))) {
+				updateHandle(f);
+			} else {
+				// Fall back to a version without the StrBuf parameter:
+				rb->pop();
+				if (Function *f = as<Function>(find(S("toS"), rb, scope)))
+					updateHandle(f);
+			}
 		}
 
 		// Find hash function.
@@ -1110,82 +1146,16 @@ namespace storm {
 
 	void Type::modifyHandle(Handle *) {}
 
-	void Type::updateHandleToS(bool first, Function *newFn) {
-		if (!value())
-			return;
+	// Check if the parameters follow the constraints required for comparison functions (i.e. < and ==) to work.
+	static Bool comparisonParams(Type *me, Array<Value> *params) {
+		if (params->count() != 2)
+			return false;
 
-		if (newFn) {
-			if (*newFn->name != S("<<"))
-				return;
+		Value lhs = params->at(0).asRef();
+		Value rhs = params->at(1).asRef();
 
-			if (newFn->params->count() != 2)
-				return;
-
-			Type *strBufT = StrBuf::stormType(engine);
-			if (newFn->params->at(0) != Value(strBufT))
-				return;
-
-			if (newFn->params->at(1).type != this)
-				return;
-
-			RefHandle *h = (RefHandle *)tHandle;
-			h->setToS(newFn);
-			handleToS = toSFound;
-
-			// TODO: Remove the notification now?
-
-			return;
-		}
-
-		if (!first && handleToS == toSFound)
-			return;
-
-		if (first || handleToS == toSNoParent) {
-			handleToS = toSMissing;
-
-			RefHandle *h = (RefHandle *)tHandle;
-
-			if (parentLookup) {
-				Array<Value> *bv = new (engine) Array<Value>(2, Value(this));
-				Type *strBufT = StrBuf::stormType(engine);
-				bv->at(0) = Value(strBufT);
-
-				Scope s = engine.scope().child(parentLookup);
-				if (Function *f = as<Function>(s.find(S("<<"), bv))) {
-					h->setToS(f);
-					handleToS = toSFound;
-				}
-			} else {
-				handleToS = toSNoParent;
-			}
-
-			if (first && handleToS != toSFound) {
-				Array<Value> *bv = new (engine) Array<Value>(2, Value(this));
-				Type *strBufT = StrBuf::stormType(engine);
-				bv->at(0) = thisPtr(strBufT);
-
-				if (Function *f = as<Function>(strBufT->find(S("<<"), bv, engine.scope()))) {
-					h->setToS(f);
-					handleToS = toSFound;
-				} else {
-					// Probably too early for this... Wait for notifications from StrBuf.
-					strBufT->watchAdd(this);
-				}
-			}
-
-			if (handleToS == toSMissing) {
-				// Find our parent...
-				NameSet *firstSet = null;
-				for (NameLookup *at = parent(); at != null && firstSet == null; at = at->parentLookup)
-					firstSet = as<NameSet>(at);
-
-				if (!firstSet)
-					return;
-
-				// Ask our parent to keep an eye out for us!
-				firstSet->watchAdd(this);
-			}
-		}
+		return lhs.mayReferTo(me)
+			&& rhs.mayReferTo(me);
 	}
 
 	void Type::updateHandle(Function *fn) {
@@ -1219,21 +1189,31 @@ namespace storm {
 					if (allRefParams(fn))
 						h->setHash(fn->ref());
 					else
-						h->hashFn = (Handle::HashFn)makeRefParams(fn);
+						h->setHash(makeRefParams(fn));
 				}
 			} else if (*name == S("==")) {
-				if (params->count() == 2) {
+				if (comparisonParams(this, params)) {
 					if (allRefParams(fn))
 						h->setEqual(fn->ref());
 					else
-						h->equalFn = (Handle::EqualFn)makeRefParams(fn);
+						h->setEqual(makeRefParams(fn));
 				}
 			} else if (*name == S("<")) {
-				if (params->count() == 2) {
+				if (comparisonParams(this, params)) {
 					if (allRefParams(fn))
 						h->setLess(fn->ref());
 					else
-						h->lessFn = (Handle::LessFn)makeRefParams(fn);
+						h->setLess(makeRefParams(fn));
+				}
+			} else if (val && *name == S("toS")) {
+				if (refThis && params->count() == 2) {
+					if (Value(StrBuf::stormType(engine)).mayStore(params->at(1)) && !params->at(1).ref) {
+						h->setToS(fn->ref());
+						handleToS = toSWithParam;
+					}
+				} else if (refThis && params->count() == 1 && handleToS != toSWithParam) {
+					h->setToS(makeToSThunk(fn));
+					handleToS = toSNoParam;
 				}
 			}
 		} else {
